package src

import (
	"context"
	"fmt"
	"net/http"
	"time"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson"
)

type EnvironmentData struct {
	Temp     float64 `json:"t" binding:"required"`
	Humidity float64 `json:"h" binding:"required"`
}

func CreateData(c *gin.Context) {
	var data EnvironmentData
	if err := c.ShouldBindJSON(&data); err != nil {
		println(err.Error())
		c.JSON(http.StatusBadRequest, gin.H{"error": err.Error()})
	} else {
		doc := data.toBSON()
		fmt.Printf("T:%f H:%f\n", data.Temp, data.Humidity)
		_, err := dbCollection.InsertOne(context.TODO(), doc)

		if err != nil {
			println(err.Error())
			c.JSON(http.StatusInternalServerError, "")
		} else {
			c.JSON(http.StatusOK, "")
		}
	}
}

func (data *EnvironmentData) toBSON() bson.M {

	return bson.M{"Temperature": data.Temp,
		"Humidity": data.Humidity,
		"Time":     time.Now().UTC(),
	}
}
